References
----------
- http://elinux.org/Rpi_Low-level_peripherals#General_Purpose_Input.2FOutput_.28GPIO.29
- http://binerry.de/post/25787954149/pcd8544-library-for-raspberry-pi
- http://www.avdweb.nl/arduino/hardware-interfacing/nokia-5110-lcd.html
- http://www.raspberrypi.org/phpBB3/viewtopic.php?f=32&t=9814&start=100
- https://projects.drogon.net/raspberry-pi/wiringpi/pins/
- http://www.henningkarlsen.com/electronics/t_imageconverter_mono.php
- https://vimeo.com/41393421
- http://fritzing.org
